@@ -8,12 +8,40 @@ use Log::ger;
 use App::orgadb::Common;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-08-05'; # DATE
+our $DATE = '2025-01-19'; # DATE
 our $DIST = 'App-orgadb'; # DIST
-our $VERSION = '0.017'; # VERSION
+our $VERSION = '0.018'; # VERSION
 
 our %SPEC;
 
+our %FEATURES = (
+    set_v => {PasswordManager => 1},
+    features => {
+        PasswordManager => {
+            can_add_password                         => 0,
+            can_add_note                             => 0,
+            can_add_custom_fields                    => 0,
+
+            can_edit_password                        => 0,
+            can_record_edit_history                  => 0,
+
+            can_delete_password                      => 0,
+
+            can_retrieve_password                    => 1,
+            can_dump_passwords                       => 1,
+
+            can_encrypt_password                     => 1,
+            can_encrypt_label                        => 1,
+            can_encrypt_other_fields                 => 1,
+
+            database_format                          => 'Org',
+            database_format_is_open_standard         => 1,
+            encryption_format                        => 'OpenPGP',
+            encryption_format_is_open_standard       => 1,
+        },
+    },
+);
+
 $SPEC{':package'} = {
     v => 1.1,
     summary => 'An opinionated Org addressbook toolset',
@@ -491,7 +519,7 @@ App::orgadb - An opinionated Org addressbook toolset
 
 =head1 VERSION
 
-This document describes version 0.017 of App::orgadb (from Perl distribution App-orgadb), released on 2023-08-05.
+This document describes version 0.018 of App::orgadb (from Perl distribution App-orgadb), released on 2025-01-19.
 
 =head1 SYNOPSIS
 
@@ -754,7 +782,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023, 2022 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2025 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
